@@ -2,7 +2,7 @@ use crate::{appstate::AppState, templates};
 use trillium::{conn_unwrap, Conn, KnownHeaderName, Status};
 use trillium_router::RouterConnExt;
 use trillium_ructe::RucteConnExt;
-use trillium_send_file::SendFileConnExt;
+use trillium_static::StaticConnExt;
 
 pub async fn get_posts(conn: Conn) -> Conn {
     let state = conn.state::<AppState>().unwrap().to_owned();
@@ -50,7 +50,5 @@ pub async fn get_attachment(conn: Conn) -> Conn {
     let post = conn_unwrap!(blog.get_post(slug), conn);
     let attachment_name = conn_unwrap!(conn.param("attachment"), conn);
     let attachment = conn_unwrap!(post.get_attachment(attachment_name), conn);
-    conn.with_header(KnownHeaderName::CacheControl, "max-age=31536000") // 1 year as a second
-        .send_file(attachment.get_path().into())
-        .await
+    conn.send_path(attachment.get_path()).await
 }
